@@ -117,6 +117,29 @@ class DBConnect:
                 other={'prompt': str(err)}
             )
 
+    def update_docu_inc(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
+        try:
+            # 将参数id处理成符合mongo格式的_id对象
+            find_docu = handle_db_id(find_docu)
+            # 排除假删除数据
+            find_docu = handle_db_remove(find_docu)
+            # 将更新内容转化为mongo能识别的更新格式
+            modify_docu = {'$inc': modify_docu,'$set':{'update_time': datetime.today()}}
+            if many:
+                student = self.mongo_collection.update_many(
+                    find_docu, modify_docu)
+            else:
+                student = self.mongo_collection.update_one(
+                    find_docu, modify_docu)
+            # 返回匹配条数、受影响条数
+            return {'matched_count': student.matched_count, 'modified_count': student.modified_count}
+        except Exception as err:
+            handle_abnormal(
+                message='MongoDB(组件)出现更新错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
+
     def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> dict:
         try:
             if false_delete:
