@@ -18,7 +18,7 @@ class Parameter():
         except json.decoder.JSONDecodeError:
             self.param_json = {}
         # 表单提交取值
-        self.param_form = request.form
+        self.param_form = dict(request.form)
 
     def get_content(self) -> dict:
         return {
