@@ -185,7 +185,7 @@ class VerifyToken:
             )
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
-        self.group_list = user['group_name']  # 用户包含的所有组别名称
+        self.group_list = user.get('group_name', [])  # 用户包含的所有组别名称
         # 合并多角色权限
         permission_list = []
         is_all_data_list = []
